
# This file was generated by 'versioneer.py' (0.15) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json
import sys

version_json = '''
{
 "dirty": false,
 "error": null,
 "full-revisionid": "b8cc94eccabfde03ef9cd527f1eeb6d69c03eaa6",
 "version": "1.2.2"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
